@@ -41,7 +41,7 @@ def get_install_files():
 @cli.command()
 def version():
     """Return the version of pb_tool and exit"""
-    click.echo("1.0a1, 2014-10-01")
+    click.echo("1.0, 2014-10-01")
 
 
 @cli.command()
